diff --git a/repos/demo/src/lib/launchpad/launchpad.cc b/repos/demo/src/lib/launchpad/launchpad.cc
index f03501ce5e..ece3c00ed1 100644
--- a/repos/demo/src/lib/launchpad/launchpad.cc
+++ b/repos/demo/src/lib/launchpad/launchpad.cc
@@ -39,7 +39,7 @@ Launchpad::Launchpad(Env &env, unsigned long initial_quota)
"RM", "PD", "CPU", "IO_MEM", "IO_PORT", "IRQ", "ROM", "LOG", "VM",
/* services expected to got started by init */
- "Nitpicker", "Init", "Timer", "Block", "Nic", "Rtc", "Gpu", "Report",
+ "Gui", "Init", "Timer", "Block", "Nic", "Rtc", "Gpu", "Report",
0 /* null-termination */
};
diff --git a/repos/gems/include/gems/wrapped_nitpicker_session.h b/repos/gems/include/gems/wrapped_gui_session.h
similarity index 89%
rename from repos/gems/include/gems/wrapped_nitpicker_session.h
rename to repos/gems/include/gems/wrapped_gui_session.h
index ec7f3aa0fc..becd0aa656 100644
--- a/repos/gems/include/gems/wrapped_nitpicker_session.h
+++ b/repos/gems/include/gems/wrapped_gui_session.h
@@ -1,10 +1,10 @@
/*
- * \brief Wrapper of a nitpicker session
+ * \brief Wrapper of a GUI session
* \author Norman Feske
* \date 2014-10-01
*
* This utility is intended to reduce repetitive boiler-plate code of
- * components that intercept the nitpicker session interface. By default,
+ * components that intercept the GUI session interface. By default,
* all RPC function calls are forwarded to the wrapped session. So the
* implementations have to override only those functions that need
* customizations.
@@ -17,8 +17,8 @@
* under the terms of the GNU Affero General Public License version 3.
*/
-#ifndef _INCLUDE__GEMS__WRAPPED_NITPICKER_SESSION_H_
-#define _INCLUDE__GEMS__WRAPPED_NITPICKER_SESSION_H_
+#ifndef _INCLUDE__GEMS__WRAPPED_GUI_SESSION_H_
+#define _INCLUDE__GEMS__WRAPPED_GUI_SESSION_H_
/* Genode includes */
#include
@@ -108,4 +108,4 @@ class Wrapped_nitpicker_session : public Genode::Rpc_object
}
};
-#endif /* _INCLUDE__GEMS__WRAPPED_NITPICKER_SESSION_H_ */
+#endif /* _INCLUDE__GEMS__WRAPPED_GUI_SESSION_H_ */
diff --git a/repos/gems/recipes/pkg/window_layouter/runtime b/repos/gems/recipes/pkg/window_layouter/runtime
index 503e2a69b1..8ad7f96507 100644
--- a/repos/gems/recipes/pkg/window_layouter/runtime
+++ b/repos/gems/recipes/pkg/window_layouter/runtime
@@ -19,7 +19,7 @@
-
+
diff --git a/repos/gems/recipes/raw/motif_wm/decorator_init.config b/repos/gems/recipes/raw/motif_wm/decorator_init.config
index 6043f6332b..10ac1836c0 100644
--- a/repos/gems/recipes/raw/motif_wm/decorator_init.config
+++ b/repos/gems/recipes/raw/motif_wm/decorator_init.config
@@ -4,7 +4,7 @@
-
+
diff --git a/repos/gems/recipes/raw/motif_wm/wm.config b/repos/gems/recipes/raw/motif_wm/wm.config
index 0651567530..d74219c690 100644
--- a/repos/gems/recipes/raw/motif_wm/wm.config
+++ b/repos/gems/recipes/raw/motif_wm/wm.config
@@ -4,7 +4,7 @@
-
+
@@ -15,7 +15,7 @@
-
+
@@ -49,7 +49,7 @@
-
+
@@ -63,7 +63,7 @@
-
+
@@ -81,7 +81,7 @@
-
+
@@ -98,7 +98,7 @@
-
+
diff --git a/repos/gems/recipes/raw/themed_wm/decorator_init.config b/repos/gems/recipes/raw/themed_wm/decorator_init.config
index 62f6389197..879a0cca70 100644
--- a/repos/gems/recipes/raw/themed_wm/decorator_init.config
+++ b/repos/gems/recipes/raw/themed_wm/decorator_init.config
@@ -4,7 +4,7 @@
-
+
diff --git a/repos/gems/recipes/raw/wm/wm.config b/repos/gems/recipes/raw/wm/wm.config
index 080f5dc4e7..a967d99475 100644
--- a/repos/gems/recipes/raw/wm/wm.config
+++ b/repos/gems/recipes/raw/wm/wm.config
@@ -4,7 +4,7 @@
-
+
@@ -15,7 +15,7 @@
-
+
@@ -77,7 +77,7 @@
-
+
@@ -91,7 +91,7 @@
-
+
diff --git a/repos/gems/run/cpu_load_display.run b/repos/gems/run/cpu_load_display.run
index 7fab81f06d..70243c74db 100644
--- a/repos/gems/run/cpu_load_display.run
+++ b/repos/gems/run/cpu_load_display.run
@@ -47,7 +47,7 @@ install_config {
-
+
@@ -60,7 +60,7 @@ install_config {
-
+
diff --git a/repos/gems/run/decorator.run b/repos/gems/run/decorator.run
index 5d5c4ca039..6f9deaf856 100644
--- a/repos/gems/run/decorator.run
+++ b/repos/gems/run/decorator.run
@@ -58,7 +58,7 @@ install_config {
-
+
diff --git a/repos/gems/run/decorator_stress.run b/repos/gems/run/decorator_stress.run
index 9af6f902a1..09b67ecef5 100644
--- a/repos/gems/run/decorator_stress.run
+++ b/repos/gems/run/decorator_stress.run
@@ -50,7 +50,7 @@ install_config {
-
+
diff --git a/repos/gems/run/depot_deploy.run b/repos/gems/run/depot_deploy.run
index 138368c174..f345681120 100644
--- a/repos/gems/run/depot_deploy.run
+++ b/repos/gems/run/depot_deploy.run
@@ -60,7 +60,7 @@ install_config {
-
+
@@ -74,7 +74,7 @@ install_config {
-
+
@@ -142,7 +142,7 @@ install_config {
-
+
@@ -165,7 +165,7 @@ install_config {
-
+
@@ -177,7 +177,7 @@ install_config {
-
+
@@ -187,27 +187,27 @@ install_config {
-
+
-
+
-
+
@@ -220,7 +220,7 @@ install_config {
-
+
@@ -255,7 +255,7 @@ install_config {
-
+
diff --git a/repos/gems/run/leitzentrale.run b/repos/gems/run/leitzentrale.run
index 5a8373c8fb..a21e2c0e9e 100644
--- a/repos/gems/run/leitzentrale.run
+++ b/repos/gems/run/leitzentrale.run
@@ -93,7 +93,7 @@ install_config {
-
+
@@ -112,7 +112,7 @@ install_config {
-
+
@@ -235,7 +235,7 @@ install_config {
-
+
@@ -245,7 +245,7 @@ install_config {
-
+
@@ -301,9 +301,9 @@ install_config {
-
+
-
+
diff --git a/repos/gems/run/menu_view.run b/repos/gems/run/menu_view.run
index 5891899165..e54b449de7 100644
--- a/repos/gems/run/menu_view.run
+++ b/repos/gems/run/menu_view.run
@@ -50,7 +50,7 @@ install_config {
-
+
@@ -64,7 +64,7 @@ install_config {
-
+
diff --git a/repos/gems/run/mixer_gui_qt_test.run b/repos/gems/run/mixer_gui_qt_test.run
index 06fdfed141..019a7d452e 100644
--- a/repos/gems/run/mixer_gui_qt_test.run
+++ b/repos/gems/run/mixer_gui_qt_test.run
@@ -79,7 +79,7 @@ append config {
-
+
diff --git a/repos/gems/run/nano3d.run b/repos/gems/run/nano3d.run
index 80570f69ae..7224538b3a 100644
--- a/repos/gems/run/nano3d.run
+++ b/repos/gems/run/nano3d.run
@@ -46,7 +46,7 @@ append config {
-
+
@@ -69,7 +69,7 @@ append config {
-
+
diff --git a/repos/gems/run/nit_fader.run b/repos/gems/run/nit_fader.run
index a4866b44ca..2c1972c30c 100644
--- a/repos/gems/run/nit_fader.run
+++ b/repos/gems/run/nit_fader.run
@@ -46,7 +46,7 @@ install_config {
-
+
@@ -59,7 +59,7 @@ install_config {
-
+
@@ -92,12 +92,12 @@ install_config {
-
+
-
+
@@ -105,7 +105,7 @@ install_config {
-
+
@@ -114,7 +114,7 @@ install_config {
-
+
diff --git a/repos/gems/run/sculpt.run b/repos/gems/run/sculpt.run
index 9064494b75..24f170a8ae 100644
--- a/repos/gems/run/sculpt.run
+++ b/repos/gems/run/sculpt.run
@@ -269,7 +269,7 @@ install_config {
-
+
@@ -338,7 +338,7 @@ install_config {
-
+
@@ -365,7 +365,7 @@ install_config {
-
+
@@ -401,7 +401,7 @@ install_config {
-
+
@@ -423,7 +423,7 @@ install_config {
-
+
@@ -461,13 +461,13 @@ install_config {
-
+
-
+
-
+
-
+
diff --git a/repos/gems/run/sculpt/empty_runtime.config b/repos/gems/run/sculpt/empty_runtime.config
index b33cc28117..02cdd4e77b 100644
--- a/repos/gems/run/sculpt/empty_runtime.config
+++ b/repos/gems/run/sculpt/empty_runtime.config
@@ -8,7 +8,7 @@
-
+
diff --git a/repos/gems/run/sculpt/leitzentrale.config b/repos/gems/run/sculpt/leitzentrale.config
index ed9cfb1081..b2b42eb479 100644
--- a/repos/gems/run/sculpt/leitzentrale.config
+++ b/repos/gems/run/sculpt/leitzentrale.config
@@ -11,7 +11,7 @@
-
+
@@ -20,7 +20,7 @@
-
+
@@ -39,10 +39,10 @@
-
+
-
+
@@ -53,10 +53,10 @@
-
+
-
+
@@ -69,14 +69,14 @@
-
+
-
+
@@ -139,7 +139,7 @@
-
+
@@ -149,7 +149,7 @@
-
+
@@ -187,7 +187,7 @@
-
+
@@ -206,7 +206,7 @@
-
+
@@ -233,7 +233,7 @@
-
+
@@ -255,7 +255,7 @@
-
+
@@ -309,7 +309,7 @@
xpos="-20" ypos="-20" />
-
+
diff --git a/repos/gems/run/terminal_log.run b/repos/gems/run/terminal_log.run
index a81ed12562..abc1b2dfa0 100644
--- a/repos/gems/run/terminal_log.run
+++ b/repos/gems/run/terminal_log.run
@@ -21,7 +21,7 @@ install_config {
-
+
@@ -50,7 +50,7 @@ install_config {
-
+
diff --git a/repos/gems/run/text_area.run b/repos/gems/run/text_area.run
index c255810a57..e0ac86fc7c 100644
--- a/repos/gems/run/text_area.run
+++ b/repos/gems/run/text_area.run
@@ -59,7 +59,7 @@ install_config {
-
+
@@ -76,7 +76,7 @@ install_config {
-
+
diff --git a/repos/gems/run/tiled_wm.run b/repos/gems/run/tiled_wm.run
index 2d76aef077..bc641343c0 100644
--- a/repos/gems/run/tiled_wm.run
+++ b/repos/gems/run/tiled_wm.run
@@ -123,7 +123,7 @@ append config {
-
+
@@ -148,7 +148,7 @@ append config {
-
+
@@ -170,7 +170,7 @@ append config {
-
+
@@ -192,7 +192,7 @@ append config {
-
+
@@ -213,7 +213,7 @@ append config {
-
+
diff --git a/repos/gems/run/wm.run b/repos/gems/run/wm.run
index d337e6eca5..d129ba6d06 100644
--- a/repos/gems/run/wm.run
+++ b/repos/gems/run/wm.run
@@ -53,7 +53,7 @@ install_config {
-
+
@@ -66,7 +66,7 @@ install_config {
-
+
@@ -75,11 +75,11 @@ install_config {
-
+
-
+
diff --git a/repos/gems/src/app/depot_autopilot/child.cc b/repos/gems/src/app/depot_autopilot/child.cc
index ff6aa315f1..a1931e0b41 100644
--- a/repos/gems/src/app/depot_autopilot/child.cc
+++ b/repos/gems/src/app/depot_autopilot/child.cc
@@ -319,7 +319,7 @@ void Child::gen_start_node(Xml_generator &xml,
_gen_provides_sub_node(xml, service, "input", "Input");
_gen_provides_sub_node(xml, service, "log", "LOG");
_gen_provides_sub_node(xml, service, "nic", "Nic");
- _gen_provides_sub_node(xml, service, "nitpicker", "Nitpicker");
+ _gen_provides_sub_node(xml, service, "nitpicker", "Gui");
_gen_provides_sub_node(xml, service, "report", "Report");
_gen_provides_sub_node(xml, service, "rom", "ROM");
_gen_provides_sub_node(xml, service, "terminal", "Terminal");
diff --git a/repos/gems/src/app/depot_deploy/child.h b/repos/gems/src/app/depot_deploy/child.h
index 535e1f8183..b2c45a18a0 100644
--- a/repos/gems/src/app/depot_deploy/child.h
+++ b/repos/gems/src/app/depot_deploy/child.h
@@ -437,7 +437,7 @@ void Depot_deploy::Child::gen_start_node(Xml_generator &xml, Xml_node common,
_gen_provides_sub_node(xml, service, "input", "Input");
_gen_provides_sub_node(xml, service, "log", "LOG");
_gen_provides_sub_node(xml, service, "nic", "Nic");
- _gen_provides_sub_node(xml, service, "nitpicker", "Nitpicker");
+ _gen_provides_sub_node(xml, service, "nitpicker", "Gui");
_gen_provides_sub_node(xml, service, "report", "Report");
_gen_provides_sub_node(xml, service, "rom", "ROM");
_gen_provides_sub_node(xml, service, "terminal", "Terminal");
diff --git a/repos/gems/src/app/sculpt_manager/model/route.h b/repos/gems/src/app/sculpt_manager/model/route.h
index 6655a6d61e..9beb0edb5f 100644
--- a/repos/gems/src/app/sculpt_manager/model/route.h
+++ b/repos/gems/src/app/sculpt_manager/model/route.h
@@ -33,7 +33,7 @@ struct Sculpt::Route : List_model::Element
case Service::Type::BLOCK: return "block";
case Service::Type::FILE_SYSTEM: return "file_system";
case Service::Type::NIC: return "nic";
- case Service::Type::NITPICKER: return "nitpicker";
+ case Service::Type::GUI: return "nitpicker";
case Service::Type::RM: return "rm";
case Service::Type::IO_MEM: return "io_mem";
case Service::Type::IO_PORT: return "io_port";
@@ -59,7 +59,7 @@ struct Sculpt::Route : List_model::Element
case Service::Type::BLOCK: return "Block device";
case Service::Type::FILE_SYSTEM: return "File system";
case Service::Type::NIC: return "Network";
- case Service::Type::NITPICKER: return "GUI";
+ case Service::Type::GUI: return "GUI";
case Service::Type::RM: return "Region maps";
case Service::Type::IO_MEM: return "Direct memory-mapped I/O";
case Service::Type::IO_PORT: return "Direct port I/O";
diff --git a/repos/gems/src/app/sculpt_manager/model/runtime_config.h b/repos/gems/src/app/sculpt_manager/model/runtime_config.h
index c9eec3aae9..fe073a203d 100644
--- a/repos/gems/src/app/sculpt_manager/model/runtime_config.h
+++ b/repos/gems/src/app/sculpt_manager/model/runtime_config.h
@@ -126,7 +126,7 @@ class Sculpt::Runtime_config
}
}
- if (service == "Nitpicker") {
+ if (service == "Gui") {
result = "GUI";
return;
}
@@ -323,10 +323,10 @@ class Sculpt::Runtime_config
Registry _r { };
Parent_service const
- _focus { _r, Type::NITPICKER, "keyboard focus", "focus" },
- _backdrop { _r, Type::NITPICKER, "desktop background", "backdrop" },
- _lockscreen{ _r, Type::NITPICKER, "desktop lock screen", "lock_screen" },
- _nitpicker { _r, Type::NITPICKER, "system GUI server" },
+ _focus { _r, Type::GUI, "keyboard focus", "focus" },
+ _backdrop { _r, Type::GUI, "desktop background", "backdrop" },
+ _lockscreen{ _r, Type::GUI, "desktop lock screen", "lock_screen" },
+ _nitpicker { _r, Type::GUI, "system GUI server" },
_config_fs { _r, Type::FILE_SYSTEM, "writeable system configuration", "config" },
_report_fs { _r, Type::FILE_SYSTEM, "read-only system reports", "report" },
_capslock { _r, Type::ROM, "global capslock state", "capslock" },
diff --git a/repos/gems/src/app/sculpt_manager/model/service.h b/repos/gems/src/app/sculpt_manager/model/service.h
index a57aa6b69e..06e4355f5f 100644
--- a/repos/gems/src/app/sculpt_manager/model/service.h
+++ b/repos/gems/src/app/sculpt_manager/model/service.h
@@ -25,7 +25,7 @@ struct Sculpt::Service
typedef String<32> Info;
enum class Type {
- AUDIO_IN, AUDIO_OUT, BLOCK, FILE_SYSTEM, NIC, NITPICKER,
+ AUDIO_IN, AUDIO_OUT, BLOCK, FILE_SYSTEM, NIC, GUI,
RM, IO_MEM, IO_PORT, IRQ, REPORT, ROM, TERMINAL, TRACE,
USB, RTC, PLATFORM, VM, UNDEFINED };
@@ -48,7 +48,7 @@ struct Sculpt::Service
case Type::BLOCK: return "Block";
case Type::FILE_SYSTEM: return "File_system";
case Type::NIC: return "Nic";
- case Type::NITPICKER: return "Nitpicker";
+ case Type::GUI: return "Gui";
case Type::RM: return "RM";
case Type::IO_MEM: return "IO_MEM";
case Type::IO_PORT: return "IO_PORT";
diff --git a/repos/gems/src/app/text_area/main.cc b/repos/gems/src/app/text_area/main.cc
index 8a94d2f44c..0b8b15e0b5 100644
--- a/repos/gems/src/app/text_area/main.cc
+++ b/repos/gems/src/app/text_area/main.cc
@@ -146,7 +146,7 @@ struct Text_area::Main : Sandbox::Local_service_base::Wakeup,
service_node("PD");
service_node("LOG");
service_node("File_system");
- service_node("Nitpicker");
+ service_node("Gui");
service_node("Timer");
service_node("Report");
});
@@ -198,7 +198,7 @@ struct Text_area::Main : Sandbox::Local_service_base::Wakeup,
});
xml.node("service", [&] () {
- xml.attribute("name", "Nitpicker");
+ xml.attribute("name", "Gui");
xml.node("local", [&] () { });
});
diff --git a/repos/libports/run/mesa.inc b/repos/libports/run/mesa.inc
index d1f2133458..d1434cd6b4 100644
--- a/repos/libports/run/mesa.inc
+++ b/repos/libports/run/mesa.inc
@@ -63,7 +63,7 @@ set config {
-
+
@@ -94,7 +94,7 @@ set launchpad_config {
-
+
diff --git a/repos/libports/run/mupdf.run b/repos/libports/run/mupdf.run
index f792812138..0ca7bbe07a 100644
--- a/repos/libports/run/mupdf.run
+++ b/repos/libports/run/mupdf.run
@@ -26,7 +26,7 @@ set config {
-
+
@@ -49,7 +49,7 @@ set config {
-
+
@@ -62,7 +62,7 @@ set config {
-
+
@@ -71,11 +71,11 @@ set config {
-
+
-
+
diff --git a/repos/libports/run/qt5.run b/repos/libports/run/qt5.run
index fe97bd87ff..cde18aadc5 100644
--- a/repos/libports/run/qt5.run
+++ b/repos/libports/run/qt5.run
@@ -74,7 +74,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_calculatorform.run b/repos/libports/run/qt5_calculatorform.run
index b3ecfb9a33..378b9decdc 100644
--- a/repos/libports/run/qt5_calculatorform.run
+++ b/repos/libports/run/qt5_calculatorform.run
@@ -45,7 +45,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_common.inc b/repos/libports/run/qt5_common.inc
index 41793c303d..aa428a01ab 100644
--- a/repos/libports/run/qt5_common.inc
+++ b/repos/libports/run/qt5_common.inc
@@ -96,9 +96,9 @@ proc qt5_start_nodes { feature_arg } {
append start_nodes {
-
+
}
- append_if [use_fb_sdl feature] start_nodes {
+ append_if [use_fb_sdl feature] start_nodes {
}
append_if [use_fb_drv feature] start_nodes {
@@ -128,7 +128,7 @@ proc qt5_start_nodes { feature_arg } {
-
+
@@ -173,13 +173,13 @@ proc qt5_start_nodes { feature_arg } {
-
-
+
+
-
-
-
+
+
+
@@ -187,7 +187,7 @@ proc qt5_start_nodes { feature_arg } {
-
+
diff --git a/repos/libports/run/qt5_openglwindow.run b/repos/libports/run/qt5_openglwindow.run
index 767be920e8..dc6fd953ff 100644
--- a/repos/libports/run/qt5_openglwindow.run
+++ b/repos/libports/run/qt5_openglwindow.run
@@ -32,7 +32,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_qpluginwidget.run b/repos/libports/run/qt5_qpluginwidget.run
index 7e0316146d..095328f4ae 100644
--- a/repos/libports/run/qt5_qpluginwidget.run
+++ b/repos/libports/run/qt5_qpluginwidget.run
@@ -53,7 +53,7 @@ append config {
-
+
@@ -71,7 +71,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_quicktest.run b/repos/libports/run/qt5_quicktest.run
index a3d798f9dd..d1de8931e4 100644
--- a/repos/libports/run/qt5_quicktest.run
+++ b/repos/libports/run/qt5_quicktest.run
@@ -53,7 +53,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_samegame.run b/repos/libports/run/qt5_samegame.run
index 49ae0e1b44..1c7cdc33e1 100644
--- a/repos/libports/run/qt5_samegame.run
+++ b/repos/libports/run/qt5_samegame.run
@@ -54,7 +54,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_testqstring.run b/repos/libports/run/qt5_testqstring.run
index 687c0cf964..f1efa3f0fd 100644
--- a/repos/libports/run/qt5_testqstring.run
+++ b/repos/libports/run/qt5_testqstring.run
@@ -46,7 +46,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_tetrix.run b/repos/libports/run/qt5_tetrix.run
index b020546cc2..2fccec1c57 100644
--- a/repos/libports/run/qt5_tetrix.run
+++ b/repos/libports/run/qt5_tetrix.run
@@ -46,7 +46,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_textedit.run b/repos/libports/run/qt5_textedit.run
index 3834d8e871..661a2eba74 100644
--- a/repos/libports/run/qt5_textedit.run
+++ b/repos/libports/run/qt5_textedit.run
@@ -67,7 +67,7 @@ append config {
-
+
@@ -89,7 +89,7 @@ append config {
-
+
diff --git a/repos/libports/run/qt5_virtualkeyboard.run b/repos/libports/run/qt5_virtualkeyboard.run
index e6b5c50f71..2e41e8667b 100644
--- a/repos/libports/run/qt5_virtualkeyboard.run
+++ b/repos/libports/run/qt5_virtualkeyboard.run
@@ -85,7 +85,7 @@ append config {
-
+
diff --git a/repos/libports/src/lib/qt5/qtbase/src/plugins/platforms/nitpicker/main.cpp b/repos/libports/src/lib/qt5/qtbase/src/plugins/platforms/nitpicker/main.cpp
index d06d27afe5..f3b1c03cfa 100644
--- a/repos/libports/src/lib/qt5/qtbase/src/plugins/platforms/nitpicker/main.cpp
+++ b/repos/libports/src/lib/qt5/qtbase/src/plugins/platforms/nitpicker/main.cpp
@@ -30,7 +30,7 @@ void initialize_qt_gui(Genode::Env &env)
QStringList QNitpickerIntegrationPlugin::keys() const
{
QStringList list;
- list << "Nitpicker";
+ list << "Gui";
return list;
}
diff --git a/repos/libports/src/test/qt5/qpluginwidget/config.plugin b/repos/libports/src/test/qt5/qpluginwidget/config.plugin
index 1a7d487c5d..ffad389613 100644
--- a/repos/libports/src/test/qt5/qpluginwidget/config.plugin
+++ b/repos/libports/src/test/qt5/qpluginwidget/config.plugin
@@ -6,7 +6,7 @@
-
+
diff --git a/repos/os/run/demo.run b/repos/os/run/demo.run
index cb20127a15..ba453ffd64 100644
--- a/repos/os/run/demo.run
+++ b/repos/os/run/demo.run
@@ -149,7 +149,7 @@ install_config {
-
+
diff --git a/repos/os/run/loader.run b/repos/os/run/loader.run
index 23ce71be91..04fb89afb5 100644
--- a/repos/os/run/loader.run
+++ b/repos/os/run/loader.run
@@ -46,7 +46,7 @@ install_config {
-
+
diff --git a/repos/os/run/pointer.run b/repos/os/run/pointer.run
index 10616a7bf1..b49b2c8b63 100644
--- a/repos/os/run/pointer.run
+++ b/repos/os/run/pointer.run
@@ -85,7 +85,7 @@ set config {
-
+
@@ -195,11 +195,11 @@ set config {
-
-
-
-
-
+
+
+
+
+
@@ -209,60 +209,60 @@ set config {
-
-
-
-
-
-
+
+
+
+
+
+
-
-
-
-
-
-
+
+
+
+
+
+
-
-
-
-
-
-
+
+
+
+
+
+
-
-
-
-
-
-
+
+
+
+
+
+
-
-
-
-
-
-
+
+
+
+
+
+
}
diff --git a/repos/os/src/server/loader/child.h b/repos/os/src/server/loader/child.h
index 7e04c7a6e4..6bd4dccd9e 100644
--- a/repos/os/src/server/loader/child.h
+++ b/repos/os/src/server/loader/child.h
@@ -58,10 +58,10 @@ class Loader::Child : public Child_policy
Service &_matching_service(Service::Name const &name)
{
- if (name == "Nitpicker") return _local_nitpicker_service;
- if (name == "ROM") return _local_rom_service;
- if (name == "CPU") return _local_cpu_service;
- if (name == "PD") return _local_pd_service;
+ if (name == "Gui") return _local_nitpicker_service;
+ if (name == "ROM") return _local_rom_service;
+ if (name == "CPU") return _local_cpu_service;
+ if (name == "PD") return _local_pd_service;
/* populate session-local parent service registry on demand */
Service *service = nullptr;
diff --git a/repos/ports/doc/gdb.txt b/repos/ports/doc/gdb.txt
index d287cfbea7..94eb95fc85 100644
--- a/repos/ports/doc/gdb.txt
+++ b/repos/ports/doc/gdb.txt
@@ -189,14 +189,14 @@ For example, the original start node of the Nitpicker GUI server as found in
the 'os/run/demo.run' run script looks as follows:
!
!
-!
+!
!
For debugging the Nitpicker service, it must be replaced with the following
snippet (see the 'debug_nitpicker.run' script at 'ports/run/' for reference):
!
!
-!
+!
!
!
diff --git a/repos/ports/recipes/pkg/vbox5/runtime b/repos/ports/recipes/pkg/vbox5/runtime
index e49a2e6720..522c8f2d70 100755
--- a/repos/ports/recipes/pkg/vbox5/runtime
+++ b/repos/ports/recipes/pkg/vbox5/runtime
@@ -27,7 +27,7 @@
-
+
@@ -67,7 +67,7 @@
-
+
diff --git a/repos/ports/recipes/raw/arora/init.config b/repos/ports/recipes/raw/arora/init.config
index 93bbd349b4..30c2fbcdbb 100644
--- a/repos/ports/recipes/raw/arora/init.config
+++ b/repos/ports/recipes/raw/arora/init.config
@@ -3,7 +3,7 @@
-
+
diff --git a/repos/ports/recipes/raw/system_shell/system_shell.config b/repos/ports/recipes/raw/system_shell/system_shell.config
index f8b0b13020..5428db62f9 100644
--- a/repos/ports/recipes/raw/system_shell/system_shell.config
+++ b/repos/ports/recipes/raw/system_shell/system_shell.config
@@ -7,7 +7,7 @@
-
+
@@ -20,7 +20,7 @@
-
+
diff --git a/repos/ports/recipes/raw/vbox5-nova-sculpt/init.config b/repos/ports/recipes/raw/vbox5-nova-sculpt/init.config
index 6e70270343..bff99ee254 100755
--- a/repos/ports/recipes/raw/vbox5-nova-sculpt/init.config
+++ b/repos/ports/recipes/raw/vbox5-nova-sculpt/init.config
@@ -6,7 +6,7 @@
-
+
@@ -57,7 +57,7 @@
-
+
diff --git a/repos/ports/run/arora.run b/repos/ports/run/arora.run
index f82c019b15..5487167f2f 100644
--- a/repos/ports/run/arora.run
+++ b/repos/ports/run/arora.run
@@ -91,7 +91,7 @@ append config {
-
+
@@ -124,7 +124,7 @@ append config {
-
+
diff --git a/repos/ports/run/debug_nitpicker.run b/repos/ports/run/debug_nitpicker.run
index 46414318e8..e9a1840a85 100644
--- a/repos/ports/run/debug_nitpicker.run
+++ b/repos/ports/run/debug_nitpicker.run
@@ -80,7 +80,7 @@ install_config {
-
+
diff --git a/repos/ports/run/seoul.inc b/repos/ports/run/seoul.inc
index 15047c472f..2813ab92ae 100644
--- a/repos/ports/run/seoul.inc
+++ b/repos/ports/run/seoul.inc
@@ -421,7 +421,7 @@ append config {
-
+
@@ -483,7 +483,7 @@ if {$use_fancy_stuff} {
-
+
diff --git a/repos/ports/run/vbox5_genode_usb_hid.run b/repos/ports/run/vbox5_genode_usb_hid.run
index 01a20a3a67..bd66d14e08 100644
--- a/repos/ports/run/vbox5_genode_usb_hid.run
+++ b/repos/ports/run/vbox5_genode_usb_hid.run
@@ -151,7 +151,7 @@ append config {
-
+
@@ -175,7 +175,7 @@ append config {
-
+
diff --git a/repos/ports/run/vbox_share.inc b/repos/ports/run/vbox_share.inc
index ad904774e4..c8ccd6d5a1 100644
--- a/repos/ports/run/vbox_share.inc
+++ b/repos/ports/run/vbox_share.inc
@@ -278,7 +278,7 @@ append config_of_app {
-
+
@@ -303,7 +303,7 @@ append config_of_app {
-
+
diff --git a/repos/ports/run/vbox_win.inc b/repos/ports/run/vbox_win.inc
index 5e6a1019ca..553c969eff 100644
--- a/repos/ports/run/vbox_win.inc
+++ b/repos/ports/run/vbox_win.inc
@@ -125,7 +125,7 @@ append config_of_app {
-
+
@@ -141,7 +141,7 @@ append config_of_app {
-
+
@@ -154,11 +154,11 @@ if { $use_vms > 1 } {
-
+
-
+
}
@@ -267,7 +267,7 @@ for { set i 1} { $i <= $use_vms } { incr i} {
}
append_if [expr ($use_vms > 1)] config_of_app {
- }
+ }
append_if [expr $use_ram_fs] config_of_app {
}
diff --git a/repos/ports/run/vim.run b/repos/ports/run/vim.run
index fc44497d94..b3eae15c21 100644
--- a/repos/ports/run/vim.run
+++ b/repos/ports/run/vim.run
@@ -66,7 +66,7 @@ install_config {
-
+
@@ -87,7 +87,7 @@ install_config {
-
+
@@ -110,13 +110,13 @@ install_config {
-
+
-
+
@@ -126,7 +126,7 @@ install_config {
-
+
diff --git a/repos/ports/run/virtualbox.run b/repos/ports/run/virtualbox.run
index 13a38d7ca1..fd31d29375 100644
--- a/repos/ports/run/virtualbox.run
+++ b/repos/ports/run/virtualbox.run
@@ -169,7 +169,7 @@ append config {
-
+
}
@@ -198,7 +198,7 @@ append config {
-
+
diff --git a/repos/ports/run/virtualbox_auto.inc b/repos/ports/run/virtualbox_auto.inc
index 639bfa6adc..431f3bd09b 100644
--- a/repos/ports/run/virtualbox_auto.inc
+++ b/repos/ports/run/virtualbox_auto.inc
@@ -237,7 +237,7 @@ append_if [expr $use_cpu_load] config {
-
+
diff --git a/repos/ports/src/app/arora/demo/nitpicker_plugin/config.plugin b/repos/ports/src/app/arora/demo/nitpicker_plugin/config.plugin
index cacfd798a4..611271d358 100644
--- a/repos/ports/src/app/arora/demo/nitpicker_plugin/config.plugin
+++ b/repos/ports/src/app/arora/demo/nitpicker_plugin/config.plugin
@@ -6,7 +6,7 @@
-
+
@@ -21,7 +21,7 @@
-
+
diff --git a/repos/os/include/gui_session/gui_session.h b/repos/os/include/gui_session/gui_session.h
index 7e2057c1c1..9dc1118ad7 100644
--- a/repos/os/include/gui_session/gui_session.h
+++ b/repos/os/include/gui_session/gui_session.h
@@ -1,9 +1,7 @@
/*
* \brief Nitpicker session interface
* \author Norman Feske
* \date 2006-08-10
- *
- * A Nitpicker session handles exactly one buffer.
*/
/*
@@ -46,7 +44,7 @@ struct Nitpicker::Session : Genode::Session
/**
* \noapi
*/
- static const char *service_name() { return "Nitpicker"; }
+ static const char *service_name() { return "Gui"; }
/*
* A nitpicker session consumes a dataspace capability for the server's
@@ -1,9 +1,7 @@
/*
- * \brief Nitpicker session interface
+ * \brief GUI session interface
* \author Norman Feske
* \date 2006-08-10